@@ -22,24 +22,17 @@
 #include "vocabsettings.h"
 #include "vocabedit.h"
 
-#include <qpushbutton.h>
-
-#include <kdebug.h>
 #include <kstandarddirs.h>
 #include <kconfigdialog.h>
-#include <qstringlist.h>
-#include <qlistwidget.h>
-#include <qvector.h>
-#include <qfile.h>
 #include <qfileinfo.h>
 
-#include <kurl.h>
-
 #include <knewstuff3/downloaddialog.h>
 #include <knewstuff3/knewstuffbutton.h>
 #include <sharedkvtmlfiles.h>
 #include <keduvocdocument.h>
-#include "kanagramsettings.h"
+#include <kanagramsettings.h>
+
+#include <QtCore/QPointer>
 
 VocabSettings::VocabSettings(QWidget *parent) : QWidget(parent), m_parent(NULL)
 {
@@ -96,11 +89,13 @@ void VocabSettings::on_btnCreateNew_clicked()
 
 void VocabSettings::on_btnDownloadNew_clicked()
 {
-    KNS3::DownloadDialog hotNewStuffdialog( "kanagram.knsrc" );
-    hotNewStuffdialog.exec();
-    if ( hotNewStuffdialog.changedEntries().size() > 0 ){
+    QPointer<KNS3::DownloadDialog> hotNewStuffdialog = new KNS3::DownloadDialog( "kanagram.knsrc" );
+    hotNewStuffdialog->exec();
+    if ( hotNewStuffdialog->changedEntries().size() > 0 ){
         refreshView();
     }
+
+    delete hotNewStuffdialog;
 }
 
 void VocabSettings::slotSelectionChanged(QTreeWidgetItem *item)
@@ -111,4 +106,3 @@ void VocabSettings::slotSelectionChanged(QTreeWidgetItem *item)
 }
 
 #include "vocabsettings.moc"
-
